// -*- C++ -*-
/*!
 * @file  PositionController.h * @brief Positional output  Controller * @date  $Date$ 
 *
 * $Id$ 
 */
#ifndef POSITIONCONTROLLER_H
#define POSITIONCONTROLLER_H

#include <rtm/idl/BasicDataTypeSkel.h>
#include <rtm/Manager.h>
#include <rtm/DataFlowComponentBase.h>
#include <rtm/CorbaPort.h>
#include <rtm/DataInPort.h>
#include <rtm/DataOutPort.h>

#include "PDControlServiceStub.h"

// Data log
#define GET_LOG
#ifdef GET_LOG
#include <fstream>
#define LOGFILE "path.dat"
#endif


using namespace RTC;

class PositionController  : public RTC::DataFlowComponentBase
{
 public:
  PositionController(RTC::Manager* manager);
  ~PositionController();

  // The initialize action (on CREATED->ALIVE transition)
  // formaer rtc_init_entry() 
  virtual RTC::ReturnCode_t onInitialize();

  // The finalize action (on ALIVE->END transition)
  // formaer rtc_exiting_entry()
  virtual RTC::ReturnCode_t onFinalize();


  // The activated action (Active state entry action)
  // former rtc_active_entry()
  virtual RTC::ReturnCode_t onActivated(RTC::UniqueId ec_id);

  // The deactivated action (Active state exit action)
  // former rtc_active_exit()
  virtual RTC::ReturnCode_t onDeactivated(RTC::UniqueId ec_id);

  // The execution action that is invoked periodically
  // former rtc_active_do()
  virtual RTC::ReturnCode_t onExecute(RTC::UniqueId ec_id);


 protected:
  // Configuration variable declaration
  std::vector<double> m_diag_Pgain;
  std::vector<double> m_diag_Dgain;
  
  // DataInPort declaration
  TimedDoubleSeq m_in0;
  InPort<TimedDoubleSeq> m_PositionInput;
  TimedDoubleSeq m_in1;
  InPort<TimedDoubleSeq> m_VelocityInput;

  // DataOutPort declaration
  TimedDoubleSeq m_TargetValue;
  OutPort<TimedDoubleSeq> m_PositionOutput;

  // CORBA Port declaration
  RTC::CorbaPort m_ConfigurationPort;

  // Consumer declaration
  RTC::CorbaConsumer<PDControlService> m_PDControlSvc0;


 private:
  unsigned long m_tick;
  double m_period;
  bool m_path_init;
  std::vector<double> m_start;
  std::vector<double> m_goal;
  std::vector<double> m_Td;

#ifdef GET_LOG
  std::ofstream m_log;
#endif
};


extern "C"
{
  void PositionControllerInit(RTC::Manager* manager);
};

#endif // POSITIONCONTROLLER_H

