/**
 * @brief  Kinematics test program
 * @author Masayuki Shimizu <tmsimiz@ipc.shizuoka.ac.jp>
 * @note   Copyright (C) 2008 Masayuki Shimizu. All Rights Reserved.
 */

#include "../fwd_kin_pa10.h"
#include <iostream>
#include <cmath>

#define RAD(deg) (deg*M_PI/180.0)

int main(int argc, char* argv[])
{
  std::vector<double> jang(7, 0.0);
  std::vector<double> jvel(7, 0.0);
  std::vector<double> x;
  std::vector<std::vector<double> > R;
  std::vector<double> V;
  fwd_kin_pa10 kin;
  int i, j;
  
  std::cout<<std::fixed;
  std::cout.precision(3);
  
#if 1
  // Kinematics
  jang[0] = RAD(45.0); // S1
  jang[1] = 0.0; // S2
  jang[2] = RAD(45.0); // S3
  jang[3] = 0.0; // E1
  jang[4] = RAD(-45.0); // W1
  jang[5] = 0.0; // W2
  jang[6] = RAD(45.0); // W3
  if(!kin.tip_pose(jang, x, R)){
    std::cout<<"kinematics error"<<std::endl;
    return -1;
  }
  std::cout<<"Joint angle [deg]:";
  for(i=0;i<7;++i)
    std::cout<<" "<<(jang[i]*180.0/M_PI);
  std::cout<<std::endl;
  std::cout<<"Tip position [m]:";
  for(i=0;i<3;++i)
    std::cout<<" "<<x[i];
  std::cout<<std::endl;
  std::cout<<"Tip orientation:"<<std::endl;
  for(i=0;i<3;++i){
    for(j=0;j<3;++j) std::cout<<" "<<R[i][j];
    std::cout<<std::endl;
  }
  std::cout<<std::endl;
#endif  
  
  std::cout.precision(6);
  
  // Instantaneous kinematics
  jang[0] = 0.0; // S1
  jang[1] = 0.0; // S2
  jang[2] = 0.0; // S3
  jang[3] = 0.0; // E1
  jang[4] = 0.0; // W1
  jang[5] = 0.0; // W2
  jang[6] = 0.0; // W3
  
  jvel[0] = 1.0; // S1
  jvel[1] = 0.0; // S2
  jvel[2] = -1.0; // S3
  jvel[3] = 0.0; // E1
  jvel[4] = -1.0; // W1
  jvel[5] = 0.0; // W2
  jvel[6] = 1.0; // W3
  
  if(!kin.tip_velocity(jang, jvel, V)){
    std::cout<<"kinematics error"<<std::endl;
    return -1;
  }
  std::cout<<"Joint angle [deg]:";
  for(i=0;i<7;++i)
    std::cout<<" "<<(jang[i]*180.0/M_PI);
  std::cout<<std::endl;
  std::cout<<"Joint velocity [deg/s]:";
  for(i=0;i<7;++i)
    std::cout<<" "<<(jvel[i]*180.0/M_PI);
  std::cout<<std::endl;
  std::cout<<"Tip linear velocity [m/s]:";
  for(i=0;i<3;++i)
    std::cout<<" "<<V[i];
  std::cout<<std::endl;
  std::cout<<"Tip angular velocity [deg/s]:";
  for(i=0;i<3;++i)
    std::cout<<" "<<(V[i+3]*180.0/M_PI);
  std::cout<<std::endl;
  
  return 0;
}
