// -*- C++ -*-
/*!
 * @file  InvKinematicsPA10.cpp * @brief Inverse Kinematics of PA10-7C arm * $Date$ 
 *
 * $Id$ 
 */
#include "InvKinematicsPA10.h"

// Module specification
// <rtc-template block="module_spec">
static const char* invkinematicspa10_spec[] =
  {
    "implementation_id", "InvKinematicsPA10",
    "type_name",         "InvKinematicsPA10",
    "description",       "Inverse Kinematics of PA10-7C arm",
    "version",           "1.0",
    "vendor",            "Masayuki Shimizu",
    "category",          "Kinematics",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    // Configuration variables
    ""
  };
// </rtc-template>

InvKinematicsPA10::InvKinematicsPA10(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_TipPositionIn("TipPosition", m_TipPosition),
    m_TipVelocityIn("TipVelocity", m_TipVelocity),
    m_RefJointAngleIn("RefJointAngle", m_RefJointAngle),
    m_JointAngleOut("JointAngle", m_JointAngle),
    m_JointVelocityOut("JointVelocity", m_JointVelocity)

    // </rtc-template>
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  registerInPort("TipPosition", m_TipPositionIn);
  registerInPort("TipVelocity", m_TipVelocityIn);
  registerInPort("RefJointAngle", m_RefJointAngleIn);

  // Set OutPort buffer
  registerOutPort("JointAngle", m_JointAngleOut);
  registerOutPort("JointVelocity", m_JointVelocityOut);

  // Set service provider to Ports

  // Set service consumers to Ports

  // Set CORBA Service Ports

  // </rtc-template>

}

InvKinematicsPA10::~InvKinematicsPA10()
{
}


RTC::ReturnCode_t InvKinematicsPA10::onInitialize()
{
  // <rtc-template block="bind_config">
  // Bind variables and configuration variable

  // </rtc-template>
  return RTC::RTC_OK;
}


/*
RTC::ReturnCode_t InvKinematicsPA10::onFinalize()
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t InvKinematicsPA10::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t InvKinematicsPA10::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t InvKinematicsPA10::onActivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t InvKinematicsPA10::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t InvKinematicsPA10::onExecute(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t InvKinematicsPA10::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t InvKinematicsPA10::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t InvKinematicsPA10::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t InvKinematicsPA10::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t InvKinematicsPA10::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


extern "C"
{
 
  void InvKinematicsPA10Init(RTC::Manager* manager)
  {
    RTC::Properties profile(invkinematicspa10_spec);
    manager->registerFactory(profile,
                             RTC::Create<InvKinematicsPA10>,
                             RTC::Delete<InvKinematicsPA10>);
  }
  
};



