// -*- C++ -*-
/*!
 * @file  PA10Manipulator.h * @brief PA10 Manipulator Component * @date  $Date$ 
 *
 * $Id$ 
 */
#ifndef PA10MANIPULATOR_H
#define PA10MANIPULATOR_H

#include <rtm/idl/BasicDataTypeSkel.h>
#include <rtm/Manager.h>
#include <rtm/DataFlowComponentBase.h>
#include <rtm/CorbaPort.h>
#include <rtm/DataInPort.h>
#include <rtm/DataOutPort.h>

#include <iostream>
#include <string>

extern "C" {
#include "pa10_library.h"
}

#include "ServoSimulatorPA10.h"
#include "ServoDriverPA10.h"
#include "VectorConvert.h"

using namespace RTC;

class PA10Manipulator  : public RTC::DataFlowComponentBase
{
 public:
  PA10Manipulator(RTC::Manager* manager);
  ~PA10Manipulator();

  // The initialize action (on CREATED->ALIVE transition)
  virtual RTC::ReturnCode_t onInitialize();

  // The finalize action (on ALIVE->END transition)
  virtual RTC::ReturnCode_t onFinalize();

  // The activated action (Active state entry action)
  virtual RTC::ReturnCode_t onActivated(RTC::UniqueId ec_id);

  // The deactivated action (Active state exit action)
  virtual RTC::ReturnCode_t onDeactivated(RTC::UniqueId ec_id);

  // The execution action that is invoked periodically
  virtual RTC::ReturnCode_t onExecute(RTC::UniqueId ec_id);

 protected:
  // Configuration variable declaration
  std::string m_mode;
  double m_tip_len;
  double m_sampling;
  std::vector<double> m_init_angles;
  // DataInPort declaration
  TimedDoubleSeq m_JointVelocity;
  InPort<TimedDoubleSeq> m_JointVelocityIn;

  // DataOutPort declaration
  TimedDoubleSeq m_CurrentJointVelocity;
  OutPort<TimedDoubleSeq> m_CurrentJointVelocityOut;
  TimedDoubleSeq m_CurrentJointAngle;
  OutPort<TimedDoubleSeq> m_CurrentJointAngleOut;
  TimedDoubleSeq m_DupCurrentJointAngle;
  OutPort<TimedDoubleSeq> m_DupCurrentJointAngleOut;

 private:

  inline void seq_to_vec(TimedDoubleSeq& s, std::vector<double>& v)
  {
    CORBA::ULong n = s.data.length();
    v.resize(n);
    for(CORBA::ULong i = 0; i < n; ++i) v[i] = s.data[i];
  }

  inline void vec_to_seq(std::vector<double>& v, TimedDoubleSeq& s)
  {
    CORBA::ULong n = v.size();
    s.data.length(n);
    for(CORBA::ULong i = 0; i < n; ++i) s.data[i] = v[i];
  }

  ServoDriverBase* m_servo;
};


extern "C"
{
  void PA10ManipulatorInit(RTC::Manager* manager);
};

#endif // PA10MANIPULATOR_H

