/**
 * @file   ServoDriverPA10.h
 * @brief  Servo driver of PA10 arm.
 * @author 
 * @note   
 */

#ifndef SERVO_DRIVER_PA10_H
#define SERVO_DRIVER_PA10_H

#include "ServoDriverBase.h"

extern "C" {
#include "pa10_library.h"
}

class ServoDriverPA10 
  : public ServoDriverBase 
{
public:
  ServoDriverPA10(unsigned long arm_id=0, enum pa10_info::TYPE type=pa10_info::PA_10A_ARM, double tipLength=0.0);
  virtual ~ServoDriverPA10();
  
  virtual bool initialize();
  virtual bool finalize();
  
  virtual bool activate();
  virtual bool deactivate();
  
  virtual bool joint_velocity_control(const std::vector<double>& joint_velocity);
  virtual bool joint_torque_control(const std::vector<double>& joint_torque);
  
  virtual bool get_current_state(std::vector<double>& joint_angle, 
				 std::vector<double>& joint_velocity);
 
private:
  // status
  bool m_initialized;
  bool m_active;
  std::vector<double> m_curr_angle;
  std::vector<double> m_curr_speed;
  
  // property
  pa10_info  *m_pa10_info;
  pa10_state *m_pa10_state;
  unsigned long m_arm_id;
  enum pa10_info::TYPE m_arm_type;
  double m_tipLength;
};

#endif /* !defined(SERVO_DRIVER_PA10_H) */
