/**
 * @file   ServoSimulatorPA10.h
 * @brief  Simulator of PA10's servo driver.
 * @author Masayuki Shimizu <tmsimiz@ipc.shizuoka.ac.jp>
 * @date   2008/10/06
 * @note   Copyright (C) 2008 Masayuki Shimizu. All Rights Reserved.
 */

#ifndef SERVO_SIMULATOR_PA10_H
#define SERVO_SIMULATOR_PA10_H

#include "ServoDriverBase.h"

#undef MINIMUM_SAMPLING_PERIOD
#define MINIMUM_SAMPLING_PERIOD (1.0e-6)  /* [s] */


class ServoSimulatorPA10 : public ServoDriverBase {
public:
  ServoSimulatorPA10(double sampling_period = 1.0e-3);
  virtual ~ServoSimulatorPA10();
  
  virtual bool initialize();
  virtual bool finalize();
  
  virtual bool activate();
  virtual bool deactivate();
  
  virtual bool joint_velocity_control(const std::vector<double>& joint_velocity);

  /**
   * @note Not supported yet.
   */
  virtual bool joint_torque_control(const std::vector<double>& joint_torque)
  { return false; }
  
  
  virtual bool get_current_state(std::vector<double>& joint_angle, 
				 std::vector<double>& joint_velocity);
  
  virtual bool set_initial_state(const std::vector<double>& joint_angle);
  virtual void get_initial_state(std::vector<double>& joint_angle);
  
  virtual bool set_sampling_period(double sampling_period);
  virtual double get_sampling_period();
  
private:
  // status
  bool m_initialized;
  bool m_active;
  unsigned long m_tick;
  std::vector<double> m_curr_angle;
  std::vector<double> m_curr_speed;
  
  // property
  std::vector<double> m_init_angle;
  double m_period;
};

#endif /* !defined(SERVO_SIMULATOR_PA10_H) */
