// -*-C++-*-
/*!
 * @file   PDControlService_impl.h
 * @brief  Service interfaces of PD Controller.
 * @author Masayuki Shimizu <tmsimiz@ipc.shizuoka.ac.jp>
 * @date   2008/10/01
 * @note   Copyright (C) 2008 Masayuki Shimizu. All Rights Reserved.
 */

#ifndef PDCONTROLSERVICE_IMPL_H
#define PDCONTROLSERVICE_IMPL_H

#include <vector>
#include "PDControlServiceSkel.h"

namespace RTC {
  
  class PDControlService_impl
    : public virtual POA_RTC::PDControlService,
      public virtual PortableServer::RefCountServantBase 
  {
  public:
    PDControlService_impl();
    virtual ~PDControlService_impl();
    
    /**
     * @brief [CORBA] Set PD gains. 
     */
    CORBA::Boolean set_gains(const DblMatrix& Kp, const DblMatrix& Kd);

    /**
     * @brief [CORBA] Get PD gains.
     */
    CORBA::Boolean get_gains(DblMatrix_out Kp, DblMatrix_out Kd);
    
    
    /**
     * @brief Check if PD gains are updated.
     */
    bool is_updated();

    /**
     * @brief Get PD gains.
     */ 
    bool read_gains(std::vector<std::vector<double> >& Kp, 
		    std::vector<std::vector<double> >& Kd);
    
    /**
     * @brief Set PD gains.
     */
    bool write_gains(const std::vector<std::vector<double> >& Kp, 
		     const std::vector<std::vector<double> >& Kd);
    
  private:
    /**
     * @brief Check if matrix is positive definite.
     */
    bool is_positive(const DblMatrix& x);
    
    bool m_updated;
    DblMatrix m_Kp;
    DblMatrix m_Kd;
    unsigned long m_dim;
  };
  
};

#endif // PDCONTROLSERVICE_IMPL_H


