/**
 * @file   VecSeqConverter.h
 * @brief  Format converter between TimedDoubleSeq and std::vector<double>.
 * @author Masayuki Shimizu <tmsimiz@ipc.shizuoka.ac.jp>
 * @date   2008/10/10
 * @note   Copyright (C) 2008 Masayuki Shimizu. All Rights Reserved.
 */

#ifndef VEC_SEQ_CONVERTER_H
#define VEC_SEQ_CONVERTER_H

#include <vector>
#include <rtm/idl/BasicDataTypeSkel.h>

/**
 * @brief Convert TimedDoubleSeq to std::vector<double>.
 */
inline void seq_to_vec(RTC::TimedDoubleSeq& s, std::vector<double>& v)
{
  CORBA::ULong n = s.data.length();
  v.resize(n);
  for(CORBA::ULong i = 0; i < n; ++i) v[i] = s.data[i];
}

/**
 * @brief Convert std::vector<double> to TimedDoubleSeq.
 */
inline void vec_to_seq(std::vector<double>& v, RTC::TimedDoubleSeq& s)
{
  CORBA::ULong n = v.size();
  s.data.length(n);
  for(CORBA::ULong i = 0; i < n; ++i) s.data[i] = v[i];
}

#endif
