/**
 * @brief Test program for PD controller
 * @author Masayuki Shimizu <tmsimiz@ipc.shizuoka.ac.jp>
 */

#include <iostream>
#include <fstream>
#include "pdcontroller.h"

#define PERIOD (0.001)

int main(int argc, char** argv)
{
  std::vector<double> target(6, 0.0);
  std::vector<double> state(6, 0.0);
  std::vector<double> speed(6, 0.0);
  std::vector<double> Kp(6, 1000.0*PERIOD);
  std::vector<double> Kd(6, 500.0*PERIOD);  // T = (1+Kd)/Kp = 1.5
  pdcontroller ctl;
  ctl.set_diag_gains(Kp, Kd);
  
  std::ofstream fs("profile.dat");
  
  // initial state
  target[0] = 1.0;
  state[0] = 0.0;
  //speed[0] = 0.0;
  speed[0] = (Kp[0]/(1+Kd[0]))*target[0];
  
  // simulation loop
  std::vector<double> u(6);
  for(int i = 0; i <= 10000; ++i){
    
    //std::cout<<state[0]<<" "<<speed[0]<<std::endl;
    fs<<(double)((double)i*PERIOD)<<" "<<state[0]<<" "<<speed[0]<<std::endl;
    
    if(!ctl.control(target, state, speed, u)){
      std::cout<<"error on control"<<std::endl;
      ::exit(1);
    }
    
    // next state
    state[0] += u[0]*PERIOD; // system: u = dx/dt
    speed[0] = u[0];
  }
  
  fs.close();
  
  return 0;
}
